# AsPubSub

Asynchronous PubSub interface for Python.

Currently Supported Back-End:
- InMemory
- Redis PubSub (support `psubscribe` and `punsubscribe`)


## Credits

- [broadcaster](https://github.com/encode/broadcaster)


